@@ -5,6 +5,8 @@ import _isNumber from 'lodash/isNumber';
 import _random from 'lodash/random';
 import _padStart from 'lodash/padStart';
 
+import draggable from '../utils/draggable';
+
 const MIN_BOX_SIZE = 23;
 const MAX_ROWS = 15;
 const MAX_COLS = 15;
@@ -151,6 +153,20 @@ export class WorldModel {
         .then((elem) => {
           console.log('drawing full canvas');
           return this.draw_canvas();
+        })
+        .then(() => {
+          $('.output-header').css({
+            width: $('.ttgt-wrapper').width() || 0,
+          });
+
+          $('.output-action-bttn').on('click', function () {
+            if ($(this).html() == '-') {
+              $(this).html('+');
+            } else {
+              $(this).html('-');
+            }
+            $('.ttgt-wrapper').slideToggle();
+          });
         });
     }
     console.log(`#${this.ui_id} already exists returning`);
@@ -159,12 +175,11 @@ export class WorldModel {
 
   skeleton() {
     return `
-    <div>
       <div id="container">
         <div class="grid">
           <div class="stats">
             <div class="stats-item">
-              <div class="stats-title">number of steps</div>
+              <div class="stats-title">Taken Moves</div>
               <div id="no_of_steps" class="stats-value">0</div> 
             </div>
             <div class="stats-item">
@@ -182,10 +197,6 @@ export class WorldModel {
           </div>
         </div>
         </div>
-        <div class="ttgt-sidebar-bttn">
-            <input class="rotate-bttn" type="button" value="Toggle" />
-        </div>
-    </div>
     `;
   }
 
@@ -195,9 +206,7 @@ export class WorldModel {
       this.skeleton().trim()
     );
     $(function () {
-      $('.ttgt-sidebar-bttn').on('click', function () {
-        $('#container').toggle();
-      });
+      draggable($('#outputArea')[0]);
     });
     this.wrapper = wrapper[0] as HTMLDivElement;
   }
@@ -240,7 +249,7 @@ export class WorldModel {
         error
       );
 
-      return Promise.reject(error);
+      return Promise.resolve(error);
     }
   }
 
