@@ -235,7 +235,36 @@ export class MazeView extends DOMWidgetView {
     this.listenTo(this.model, 'change:current_call', this.method_changed);
     if (!this.world_model) {
       this.world_model = new WorldModel();
-      this.el.appendChild(this.world_model.wrapper);
+      this.initOutput(this.world_model);
     }
   }
+
+  initOutput(world_model: WorldModel) {
+    if ($('#outputArea').length === 0) {
+      $('body')
+        .append(this.outputBody())
+        .promise()
+        .then(() => {
+          $('#outputArea').append(this.outputHeader());
+          $('#outputArea').append(world_model.wrapper);
+        });
+    } else {
+      $('#outputArea').append(world_model.wrapper);
+    }
+  }
+
+  outputBody() {
+    let op = $('<div >', { id: 'outputArea' });
+    return op;
+  }
+
+  outputHeader() {
+    return `
+      <div class="output-header">
+        <div class="output-actions">
+          <button class="output-action-bttn">-</button>
+        </div>
+      </div>
+    `;
+  }
 }
